==> haskell-data-default-0.7.1.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default
version:              0.7.1.1
visibility:           public
id:                   data-default-0.7.1.1-I5ttmgUOL407qEVhfvYDbu
key:                  data-default-0.7.1.1-I5ttmgUOL407qEVhfvYDbu
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  5daaa52409bb9eed78a12a4cfa27e93e
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-default-0.7.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-default-0.7.1.1
hs-libraries:         HSdata-default-0.7.1.1-I5ttmgUOL407qEVhfvYDbu
depends:
    base-4.14.0.0 data-default-class-0.1.2.0-AZTcEqCsR4uCdCN1ROsSjZ
    data-default-instances-containers-0.0.1-KXV1rMCzRCs7bYjTWUC2f4
    data-default-instances-dlist-0.0.1-3ijMwNbI0NMAPeflX3xoOx
    data-default-instances-old-locale-0.0.1-H7fDL7E5wHc1SuLZwtVYXn

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-0.7.1.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default
version:              0.7.1.1
visibility:           public
id:                   data-default-0.7.1.1-KKlNqfYiolkKRrpSgrKBsu
key:                  data-default-0.7.1.1-KKlNqfYiolkKRrpSgrKBsu
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  d631cc567ed718060c5ff8d548c02e9c
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-default-0.7.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-default-0.7.1.1
hs-libraries:         HSdata-default-0.7.1.1-KKlNqfYiolkKRrpSgrKBsu
depends:
    base-4.14.0.0 data-default-class-0.1.2.0-AZTcEqCsR4uCdCN1ROsSjZ
    data-default-instances-containers-0.0.1-KXV1rMCzRCs7bYjTWUC2f4
    data-default-instances-dlist-0.0.1-FrTskbRdPLL68q9zi7ICkV
    data-default-instances-old-locale-0.0.1-H7fDL7E5wHc1SuLZwtVYXn

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
